%%% Inversion for layered model 
%%% ============================================================

addpath matlab/		% use processing codes from directory matlab/
addpath modeling/	% use modeling codes from this directory

%% Processing parameters can be passed to the various codes by using
%% global structure 'procdata'. 
%% First, set up the initial values of the fields in this structure:

global procdata

procdata_default()

% several other global variables for data exchange between modeling functions 
% and interactive inspection
 
global model bfun inversion freq vphase vgroup

% set up an array of desired HALF-WAVELENGTHS for output (in meters)
% These half-wavelengths are roughly the expected depths of sampling

lambda2 = [ 0.5 : 0.25 : 20 ];	

%% you will need to perform the following steps with
%% FFID numbers = 143, 153, 163, and 172
%% The data for these FFIDs are provided in directory data/
%% ========================================================================

% 1) load the data into structures 'rec' (records), 'spec' (spectra) 
%	and 'disp' (phase-velocity semnblance)
%    Note that this call also returns the .mat file name from which these data
%	are loaded, so that you can save the modeling results in the same file later

[ rec, spec, dispsemb, matfile ] = record_ffid(153);

% plot and view the section

plot_ffid1(rec,0.6)		

% plot and view dispersion results, identify the fundamental mode in the plot:

plot_dispersion(rec,spec,dispsemb)

% set zoom-in parameters for dispersion semblance display

procdata.plot_slwns_range = [ 0, 15.0 ];	% slowness range
procdata.plot_freq_range = [ 0, 0.12 ];		% frequency range (kHz)

%% Begin modeling and inversion
%% Set up model (columns are depth at bottom, density, P-wave velocity, S-wave velocity, 
%%		P-wave viscosity, S-wave viscosity (don't worry about the last two))

model0 = [	0.5,	1.53,	0.192,	0.096,	0.0,	0.0		
		2.0,	1.53,	0.222,	0.111,	0.0,	0.0			
		5.0,	1.13,	0.35,	0.175,	0.0,	0.0	
		8.0,	1.13,	0.5,	0.25,	0.0,	0.0	
		15.0,	1.13,	0.6,	0.3,	0.0,	0.0	
		35.0,	1.53,	0.8,	0.4,	0.0,	0.0
	];

% To simplify adjustment of the model, we will only vary factors to multiply
% the P- and S-wave velocities in each layer.
% This column should have the same number of rows as in 'model0': 

scale_V = [	1
		1
		1
		1
		1
		1
	];

% Set up global variable 'model' using one the velocity-density columns above:

set_model(model0,scale_V);

% Model phase and group velocities at wavenumbers corresponding to lambda2:

[ freq, vphase, vgroup ] = modes_rayleigh( pi*lambda2.^(-1) );

%% save model and all previous data in the same .mat file 
  
if inOctave()
  	save(matfile,'-mat7-binary','rec','spec','dispsemb','model','freq','v*');
else
  	save(matfile,'rec','spec','dispsemb','model','freq','v*');
end

%% plot in figure 101 phase velocities and slownesses for three lowest modes

plot_modes( freq, vphase, dispsemb, 3, 101 )



