%% Dispersion analysis for an FFID (slowness version)
%% =====================================================================
%% 	For a given FFID, this function measured phase-velocity spectra 
%%	in structure 'dispsemb', displays them and saves in the same files as 
%%	data structures 'rec' and 'spec'
%%
%%	General processing parameters need to be provided in structure 'procdata':
%%
%%	Creates a plot in figure(31)
%%
%% Parameters:
%%	ffid - FFID number for which to create phase-velocity spectra

%% Usage examples:
%%	measure_dispersion(150)

function measure_dispersion(ffid)

global procdata

  % load record, spectra, and also obtain the file name

  [ rec, spec, ~, dataf ] = record_ffid(ffid);

  dispsemb = semblance_vphase(rec,spec,procdata);

  %% plot the semblance and its peaks

  figure(31)	
  clf

  plot_dispersion(rec,spec,dispsemb)

  %% save dispersion measurement results
  
  if inOctave()
  	save(dataf,'-mat7-binary','rec','spec','dispsemb');
  else
  	save(dataf,'rec','spec','dispsemb');
  end

end

