%% Dispersion analysis for an FFID (slowness version)
%% =====================================================================
%% 	For a given FFID, this function measured phase-velocity spectra 
%%	in structure 'dispsemb', displays them and saves in the same files as 
%%	data structures 'rec' and 'spec'
%%
%%	General processing parameters need to be provided in structure 'procdata':
%%
%%	Creates a plot in figure(31)
%%
%% Parameters:
%%	rec - structure containing waveforms
%%	spec - structure containing spectra
%%	dispsemb - structure containing dispersion semplance and picks

function plot_dispersion(rec,spec,dispsemb)

global procdata

  aoffs = abs(rec.offset);

  subplot(1,2,1)		% plot waveforms
  hold on

  % plot the moveout range by green lines

  plot( rec.chan, aoffs/dispsemb.phase_vel(1), '-g')
  plot( rec.chan, aoffs/dispsemb.phase_vel(2), '-g')
  plot( rec.chan, aoffs/dispsemb.phase_vel_expected, '--g')

  % plot the offset ranges by vertical magenta lines

  linestyle = '-m';

  for i=1:size(dispsemb.offset_range,1)
	ch = interp1(rec.offset,rec.chan,dispsemb.offset_range(i,1));

	plot( [ch ch], [ spec.time_range(1), spec.time_range(4) ],linestyle)

	ch = interp1(rec.offset,rec.chan,dispsemb.offset_range(i,2));

	plot( [ch ch], [ spec.time_range(1), spec.time_range(4) ],linestyle)

	ch = interp1(rec.offset,rec.chan, -dispsemb.offset_range(i,1));

	plot( [ch ch], [ spec.time_range(1), spec.time_range(4) ],linestyle)

	ch = interp1(rec.offset,rec.chan, -dispsemb.offset_range(i,2));

	plot( [ch ch], [ spec.time_range(1), spec.time_range(4) ],linestyle)

	linestyle = '--m';	% for overtone modes
  end

  % plot waveforms

  plot_ffid1(rec,0.6,spec.time_range)

  subplot(1,2,2)		% plot dispsemb.semblance

  plot_semblance1(dispsemb)

  title(sprintf('Phase semblance FFID %d; chan %d - %d',rec.ffid, dispsemb.chans(1), dispsemb.chans(end)))

end

