%% Plotting commands for displaying traces 'rec' in current window
%% ========================================================================
%% Parameters:
%%	rec - record to display
%%	gain - trace excursion gain for plotting
%%	time_range - 4-element array representing a time range in the record
%%
%% Usage examples:
%%	plot_ffid(rec)
%%	plot_ffid(rec,0.6)

function plot_ffid1(rec, gain, time_range)

  if nargin < 3
	time_range = [];
  end

  if isempty(rec)
	error("rec is empty")
  end

  % only plot not killed records

  ind = find(~ismember(rec.chan,rec.kill));

%%  Scale every record by peak value and gain

  hold on

  for i=1:length(ind)
	i1 = ind(i);
	chan = rec.chan(i1);

	d = rec.data(:,i1);
	t = rec.times;

 	plot(d/(max(abs(d))+1.0e-8)*gain+chan,t,'b-')
  end

  % draw the time range in which the spectra are calculated

  if ~isempty(time_range)
  	plot( [ rec.chan(1), rec.chan(end) ], [ time_range(1), time_range(1)], '-r' )
  	plot( [ rec.chan(1), rec.chan(end) ], [ time_range(2), time_range(2)], '-k' )
  	plot( [ rec.chan(1), rec.chan(end) ], [ time_range(3), time_range(3)], '-k' )
  	plot( [ rec.chan(1), rec.chan(end) ], [ time_range(4), time_range(4)], '-r' )
  end

  ylim([ rec.times(1), rec.times(end)])

  set(gca,'XTick',1:2:rec.chan(end),'YTick',0:20:max(t));
  set(gca,'Ydir','reverse');

  ylabel("Time (ms)")
  xlabel("Channel number / Ground velocity")
  title( sprintf("FFID %d", rec.ffid ) )

end

