%%  Processes all FFID data files one by one using the specified program 
%%
%% Parameters:
%%	proc_fun - function handle or name for processing each ffid. This function
%%		should take a single argument equal the FFID number
%%	close_fun - function handle or name for finalizing processing after proc_fun()
%%		returns. If close_fun=[], this function is not called.
%%		For example, use close_fun = @ginput to pause processing 
%%		until the user presses a key.
%%		The function can also output strings that can be used to control processing.
%%		If close_fun() returns string 'stop' or 'q', processing is terminated.
%%	dataset - string parameter. If dataset='raw', raw field records
%%		from directory 'mat/' are used. If dataset='edited', [], or any other,
%%		edited data from directory 'data/' are used.
%%		If this parameter is not given, 'edited' is assumed
%%	select - list of ffids to select. If select==[], all ffids are tried
%%
%% Usage examples:
%%	proc_ffids(@edit_ffid,@ginput)
%%	proc_ffids(@edit_ffid,@ginput,'raw', [ 111, 120:130 ])

function proc_ffids(proc_fun, close_fun, dataset, select)

global procdata

  if nargin < 2
	close_fun=[];
  end

  if nargin < 3
	dataset=[];
  end

  if nargin < 4
	select=[];
  end

  %% list all ffids and process them one by one

  if isempty(dataset)
  	ffid = list_ffids('data/');
  elseif strcmpi(dataset,'raw')
  	ffid = list_ffids('mat/');
  else
  	ffid = list_ffids('data/');
  end

  for i=1:length(ffid)

	if ismember(ffid(i),procdata.drop_ffid)		% skip FFIDs in drop list
		continue
	end

	if ~isempty(select)
		if ~ismember(ffid(i),select)		% skip
			continue
		end
	end

	proc_fun(ffid(i));

	if ~isempty(close_fun)
		status = close_fun();

		if strcmpi(status,'stop') || strcmpi(status,'q')
			break
		end
	end
  end
end

