%% Converts the data in files data/*.mat into SEGY by using igeos/tosegy.job

%% Parameters:
%%	project - name of the project to convert. Empty value means current project
%% Returns:
%%	lineno - list of line numbers to convert. Empty value means to convert
%%		all files in project mat/ directory into file data.sgy, 
%%		without checking line numbers
%% ============================================================================================

function tosegy( lineno=[] )
  
global procdata

  if isempty(lineno)			% output everything from data/

	fname = "data.sgy";

  	comm = [ "rm igeos/procdir; ln -s " d "proc igeos/procdir; " exec_igeos() ...
				" igeos/tosegy.job " d " mat " fname ];
    	system(comm);

  else				% output selected lines

	dtmp = "tmp/";

	mkdir(dtmp);

	for i = 1:length(lineno)

		% extract records from log file

		fname = sprintf("log_line%02d.txt",lineno(i));

		[~,ffid] = params_line(fname);

		% create temporary .mat files in directory tmp/

		for j = 1:length(ffid)

  			%% load edited record

  			rec = record_ffid(ffid(j));

			if ~isempty(rec)

				% create additional variables not included in 'rec' for mapping into SEGY

				espnum = rec.source;
				timing = [ rec.times(1), rec.times(2)-rec.times(1) ];
				line = rec.line(1);
				rec_x = transpose(rec.rec_xyz(:,1));
				rec_y = transpose(rec.rec_xyz(:,2));
				relev = transpose(rec.rec_xyz(:,3));
				sou_x = transpose(rec.src_xyz(:,1));
				sou_y = transpose(rec.src_xyz(:,2));
				selev = transpose(rec.src_xyz(:,3));

				% mark traces by header 'datuse' (trace header bytes 35:36):
				%	datause = 1 for good traces
				%	datause = 2 for killed traces

	% t	datause	:  35   2  integer  integer Data use code: 1 = production, 2 = test

				datause = ismember(rec.chan,rec.kill)+1;
	
	% use SEGY revision 1 headers to store source and receiver station numbers and inline  coordinates:

	% t	cdp_x	: 181   4  integer    float X-coordinate of ensemble (CDP) position
	% t	cdp_y	: 185   4  integer    float Y-coordinate of ensemble (CDP) position

				cdp_x = reshape(rec.rec_x, 1, []);	% receiver coordinates
				cdp_y = rec.src_x;			% source coordinate

	% t	iline	: 189   4  integer  integer In-line number in 3-D stacked data (constant for 2-D data)
	% t	sp_num	: 197   4  integer  integer Shot point number (nearest station to the source in 2D)

				iline = rec.rec_stn;		% receiver station number

				sp_num = rec.src_stn;		% source station number

				fname = sprintf("%sf%05d.mat",dtmp,ffid(j));

				save(fname,"line","espnum","timing","datause",...
						"rec_x","rec_y","relev",...
						"sou_x","sou_y","selev",...
						"iline","sp_num", ...
						"rec");	
			end
		end

		fname = sprintf("data_line%02d.sgy",lineno(i));

  		comm = sprintf("%s igeos/tosegy.job %1.0f %1.0f %s", exec_igeos(), 
					-procdata.time_start, procdata.record_length, fname );
    		system(comm);	

		% delete the temporary .mat files

		system([ "rm " dtmp "*mat"] );	
	end
  end

end

