%% Modeling Rayleigh-wave velocities in a layered structure described
%% in global structure 'model' 

%% Parameters:
%%	kx - array of horizontal wavenumbers for modeling
%% Return values:
%%	freq - matrix of complex-valued frequencies for each mode, 
%%		Columns of this matrix correspond to the elements of kx. 
%%		Rows of each column correspond to increasing wave mode orders. 
%%	vphase - matrix of complex-valued phase velocities, formatted as 'freq' 
%		If wavenumber bfun.kx==0, values vphase = 0 are output
%%	vgroup - matrix of complex-valued group velocities, formatted as 'freq'
%%		If wavenumber bfun.kx==0, values vgroup = 0 are output

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ freq, vphase, vgroup ] = modes_rayleigh(kx)

global model

  nk = length(kx);

  % initialize output matrices

  freq = zeros(model.num_modes_PSV,nk);		% output frequencies, row index is mode number
  vphase = freq;				% phase velocities

%dlam = model.lambda - model.lambda0
%dmu = model.mu - model.mu0

  % for each wavenumber, output frequencies and phase velocities for each mode

  for i=1:nk
  	basis_rayleigh(kx(i));
	[ vphase(:,i), freq(:,i) ] = vel_rayleigh();
  end

  if nargout >= 3		% need group velocities

    vgroup = zeros(size(freq));

    for i=1:size(freq,1)
    	ind = find(vphase(i,:) > 1.0e-8);  % columns in which kx != 0

      	vgroup(i,ind) = vel_group(freq(i,ind),vphase(i,ind));
    end
  end

end

