%% Scales the model by parameters 'par'
%% Vp and Vs in each layer are multiplied by values in 'par', and all moduli
%% multiplied by squares of 'par'
%% -------------------------------------------------------------------------
%%
%% Parameters:
%%	par - array of scaling factors for each layer of the model
%%		if par = [] or absent, original model (model.vp0, model.vs0) is restored
%% ================================================================================

function scale_model(par)

global model

  if nargin < 1
	par = [];
  end

  if isempty(par)
  	model.vp = model.vp0;
  	model.vs = model.vs0;

  	model.mu = model.mu0;
  	model.lambda = model.lambda0;
  	model.l2mu = model.l2mu0;

	return
  end

  % scale vp, vs by parameters 'par', and change the elastic moduli accordingly

  p2 = par.^2;

  model.vp = model.vp0 .* par;
  model.vs = model.vs0 .* par;

  model.mu = model.mu0 .*p2;
  model.lambda = model.lambda0 .* p2;
  model.l2mu = model.l2mu0 .* p2;

end

